<?php
/**
 * WooCommerce AvaTax
 *
 * This source file is subject to the GNU General Public License v3.0
 * that is bundled with this package in the file license.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.html
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@skyverge.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade WooCommerce AvaTax to newer
 * versions in the future. If you wish to customize WooCommerce AvaTax for your
 * needs please refer to http://docs.woocommerce.com/document/woocommerce-avatax/
 *
 * @author    SkyVerge
 * @copyright Copyright (c) 2016-2022, SkyVerge, Inc.
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GNU General Public License v3.0
 */

namespace SkyVerge\WooCommerce\AvaTax\API\Responses;

use WC_AvaTax_API_Response;
use WC_AvaTax;

defined( 'ABSPATH' ) or exit;

/**
 * The AvaTax API nexus list response class.
 *
 * @since 1.13.0
 */
class Nexus_List_Response extends WC_AvaTax_API_Response {


	/**
	 * Gets the supported country list from Nexus.
	 *
	 * @since 1.13.0
	 *
	 * @return string[]
	 */
	public function get_country_list() : array {
		// initialize an empty result array
		$result = [];
		$api_response = $this->filter_available_locations($this->response_data->value);

		$result = array_merge($result, $api_response);
		$nextLink = $this -> get_next_link($this->response_data);

		// If / while nextLink is present in response, enrich the result[]
		while(!empty($nextLink)) {
			$token_array = explode("/v2", $nextLink);
			$paginated_url = end($token_array);
			$paginated_response = WC_AvaTax::instance()->get_api()->get_nexus_list($paginated_url);
			$partial_response = $this->filter_available_locations($paginated_response->response_data->value);
			$result = array_unique(array_merge($result, $partial_response));
			$nextLink = $this -> get_next_link($paginated_response -> response_data);
		}

		return $result;
	}

	/**
	 * Provides filtered locations (countries) from the response
	 *
	 * @param mixed $value
	 * @return string[]
	 */
	private function filter_available_locations($value) {
		// filters all the available locations to get only their countries
		return array_unique( array_map( static function( $location ) {
			return $location->country;
		}, $value ?? [] ));
	}

	/**
	 * Provides nextLink if available in response, if not then ''
	 *
	 * @param mixed $response_data
	 * @return string
	 */
	private function get_next_link($response_data) {
		if (isset($response_data ->{'@nextLink'})) {
			return $response_data ->{'@nextLink'};
		}
		return '';
	}

}
